# QAILab

## About project

QAILab is a high level library, which enables the user to integrate quantum neural networks of different configurations into their existing PyTorch neural networks.  
The library aims to support a large amount of backends from different quantum computer manufacturers, such as IBM, AQT and Orca Computing, via its integration with Quantum Launcher.

## Installation

You can install QAILab via pip:
```sh
pip install qailab
```

## Examples and tutorials

Examples and tutorials are available in the [QAILab documentation]()